
.. image:: https://github.com/PetroFit/petrofit/raw/main/docs/images/petrofit_full_logo.png
    :width: 100%

PetroFit
--------
|circleci tag| |rtd tag| |PyPI tag| |astopy tag| |photutils tag| |zonodo tag|

PetroFit is a package for calculating Petrosian properties, such as radii and concentration indices, as well as fitting
galaxy light profiles. This package includes tools for performing accurate photometry, segmentations, Petrosian properties
and fitting. Please see the `petrofit documentation <https://petrofit.readthedocs.io/en/latest/>`_ for installation instructions and a guide to the `petrofit` module.

.. image:: https://github.com/PetroFit/petrofit/raw/main/docs/images/multi_fit.png
    :width: 100%

License
-------

This project is Copyright (c) The PetroFit Team and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause license. See the licenses folder for
more information.


Contributing
------------

We love contributions! petrofit is open source,
built on open source, and we'd love to have you hang out in our community.

**Imposter syndrome disclaimer**: We want your help. No, really.

There may be a little voice inside your head that is telling you that you're not
ready to be an open source contributor; that your skills aren't nearly good
enough to contribute. What could you possibly offer a project like this one?

We assure you - the little voice in your head is wrong. If you can write code at
all, you can contribute code to open source. Contributing to open source
projects is a fantastic way to advance one's coding skills. Writing perfect code
isn't the measure of a good developer (that would disqualify all of us!); it's
trying to create something, making mistakes, and learning from those
mistakes. That's how we all improve, and we are happy to help others learn.

Being an open source contributor doesn't just mean writing code, either. You can
help out by writing documentation, tests, or even giving feedback about the
project (and yes - that includes giving feedback about the contribution
process). Some of these contributions may be the most valuable to the project as
a whole, because you're coming to the project with fresh eyes, so you can see
the errors and assumptions that seasoned contributors have glossed over.

Note: This disclaimer was originally written by
`Adrienne Lowe <https://github.com/adriennefriend>`_ for a
`PyCon talk <https://www.youtube.com/watch?v=6Uj746j9Heo>`_, and was adapted by
petrofit based on its use in the README file for the
`MetPy project <https://github.com/Unidata/MetPy>`_.



.. |circleci tag| image:: https://circleci.com/gh/PetroFit/petrofit/tree/main.svg?style=svg
    :target: https://circleci.com/gh/PetroFit/petrofit/tree/main
    :alt: PetroFit circleci status

.. |rtd tag| image:: https://readthedocs.org/projects/petrofit/badge/?version=latest
    :target: https://petrofit.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |astopy tag| image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: https://pypi.org/project/astropy
    :alt: Powered by Astropy
    
.. |photutils tag| image:: http://img.shields.io/badge/powered%20by-PhotUtils-blue.svg?style=flat
    :target: https://pypi.org/project/photutils/
    :alt: Powered by Astropy

.. |PyPI tag| image:: https://img.shields.io/pypi/v/petrofit?color=blue
    :target: https://pypi.org/project/petrofit/
    :alt: PetroFit's PyPI Status
    
.. |zonodo tag| image:: https://zenodo.org/badge/348478663.svg
    :target: https://zenodo.org/badge/latestdoi/348478663
    :alt: PetroFit Zenodo DOI


